Crate canonical_host

Crate canonical_host 

The host library responsible for running and connecting modules

Structs

DiskStore
An in-memory store implemented with a hashmap
MemStore
An in-memory store implemented with a hashmap
Remote
A representation of a Module of erased type, with its root state reachable from the Id in the store.

Enums

DiskError
Errors that can happen using the DiskStore.
MemError
Errors that can happen using the MemStore.