The host library responsible for running and connecting modules
Structs
- Disk
Store - An in-memory store implemented with a hashmap
- MemStore
- An in-memory store implemented with a hashmap
- Remote
- A representation of a Module of erased type, with its root state reachable from the Id in the store.